/************************************************************************
 *   Purpose:  Implementation file for RatNum class
 ************************************************************************/
#include <iostream>
#include <algorithm>
#include <cassert>
#include "ratnum.h"

using namespace std;

//-----------Default-value constructor-----------
RatNum::RatNum ()
{
	myA = 0;
	myB = 1;
}

//-----------Explicit-value constructor----------
RatNum::RatNum (int numerator, int denominator)
{
	myA = numerator;
	myB = denominator;
	assert (myB != 0);
	if (myB == 0)
		cerr << "Denominator can not be 0." << endl;
}
//Reduce number to lowest terms
RatNum RatNum::reduce(RatNum &r) const
{
	int gcf_num = gcf(r.myA, r.myB);
	r.myA /= gcf_num;
	r.myB /= gcf_num;
	return r;
}

//Greatest common factor
int RatNum::gcf(int num1, int num2) const
{
	int i;
	if (num2 > num1)
		swap(num1, num2);
	for (i = num1; i > 1; i--)
	{
		if ((num1 % i == 0) && (num2 % i == 0))
		{
			num1 /= i;
			num2 /= i;
		}
	}
	return i;
}

//Least common denominator
int RatNum::lcd(RatNum r1, RatNum r2) const
{
	int num1 = r1.B(), num2 = r2.B();
	int common_factor = gcf(num1, num2);
	int product = num1 * num2;
	if (product < 0)
		product = -product;
	return product/common_factor;
}

//overload '+'
RatNum RatNum::operator +(const RatNum& r) const
{
	RatNum temp;
	temp.myA = myA + r.myA;
	temp.myB = myB + r.myB;
	return reduce(temp);
}

//overload '-'
RatNum RatNum::operator -(const RatNum &r) const
{
	RatNum temp;
	temp.myA = myA - r.myA;
	temp.myB = myB - r.myB;
	return reduce(temp);
}

//overload '*'
RatNum RatNum::operator *(const RatNum &r) const
{
	RatNum temp;
	temp.myA = myA * r.myA;
	temp.myB = myB * r.myB;
	return reduce(temp);
}

//overload '/'
RatNum RatNum::operator /(const RatNum &r) const
{
	RatNum temp;
	temp.myA = myA / r.myA;
	temp.myB = myB / r.myB;
	return reduce(temp);
}

bool RatNum::operator ==(const RatNum& r) const
{
	//'this' refers to the rational number object being executed
	return (this->myA ==r.myA && this->myB == r.myB);
}

bool RatNum::operator <(const RatNum& r) const
{
	//'this' refers to the rational number object being executed
	RatNum tmp_num = *this - r;
	return (tmp_num.myA < 0 || tmp_num.myB < 0);
}

bool RatNum::operator >(const RatNum& r) const
{
	//'this' refers to the rational number object being executed
	RatNum tmp_num = *this -r;
	return (tmp_num.myA > 0 && tmp_num.myB > 0);
}

bool RatNum::operator <=(const RatNum& r) const
{
	//'this' refers to the rational number object being executed
	RatNum tmp_num = *this -r;
	return (tmp_num.myA <= 0 || tmp_num.myB < 0);
}

bool RatNum::operator >=(const RatNum& r) const
{
	//'this' refers to the rational number object being executed
	RatNum tmp_num = *this -r;
	return (tmp_num.myA >= 0 && tmp_num.myB > 0);
}