/**************************************************************************
 *   Purpose:  Perform rational number arithmetic, where a rational number is
 *		of the form "a/b", where a and b are integers and b != 0.
 ***************************************************************************/
#include <iostream>
#include <algorithm>
#include "ratnum.h"

using namespace std;

void enterFunction(RatNum& n1, RatNum& n2);

int main ()
{
	cout << "This program performs rational number operations.  A rational number is\n"
		<< "in the form \"a/b\", where a and b are integers and b != 0.\n\n"
		<< "The following operations are available (with examples given):\n"
		<< "1. Addition (3/8 + 1/6 = 13/24)\n"
		<< "2. Subtraction (3/8 - 1/6 = 5/24)\n"
		<< "3. Multiplication (3/8 * 1/6 = 1/16)\n"
		<< "4. Division (3/8 / 1/6 = 9/4)\n"
		<< "5. Inversion (3/8 I = 8/3)\n"
		<< "6. Mixed fraction (8/3 M = 2 + 2/3)\n"
		<< "7. Reduce (6/8 R = 3/4)\n"
		<< "8. Greatest common divisor (6/8 G = 2)\n"
		<< "9. Lowest common denominator (1/6 L 3/8 = 24)\n"
		<< "10. Less than? (1/6 < 3/8 = true)\n"
		<< "11. Less than or equal to? (1/6 <= 3/8 = true)\n"
		<< "12. Greater than? (1/6 > 3/8 = false)\n"
		<< "13. Greater than or equal to? (1/6 >= 3/8 = false)\n"
		<< "14. Equality (3/8 = 9/24 = true)\n"
		<< "15. Linear equation (2/3 X +2 = 4/5) (X = -9/5)\n"
		<< "16. Quit this program\n"
		<< endl;

		int op_choice;
		do
		{
			cout << "Enter the number of one of the operations listed above."
				<< endl;
			RatNum num1, num2;
			cin >> op_choice;

			//choose number operation
			switch (op_choice)
			{
				case 1:	//add
				{
					enterFunction(num1, num2);
					RatNum sum = num1 + num2;
					cout << "\n" << num1 << "+" << num2 << "=" << sum << endl;
				}
				break;

				case 2:	//subtract
				{
					enterFunction(num1, num2);
					RatNum difference = num1 - num2;
					cout << "\n" << num1 << "-" << num2 << "=" << difference << endl;
				}
				break;

				case 3:	//multiply
				{
					enterFunction(num1, num2);
					RatNum product = num1 * num2;
					cout << "\n" << num1 << "*" << num2 << "=" << product << endl;
				}
				break;

				case 4:	//divide
				{
					enterFunction(num1, num2);
					RatNum quotient = num1 / num2;
					cout << "\n" << num1 << "/" << num2 << "=" << quotient << endl;
				}
				break;

				case 5:	//invert
				{
					RatNum invert;
					int top = invert.A(), bottom = invert.B();
					cout << "Enter the number to invert." << endl;
					cin >> invert;
					swap(top, bottom);
					cout << invert;
				}
				break;

				case 6:
				//mixed fraction
				break;

				case 7:	//reduce
				{
					RatNum input;
					cout << "Enter the number to reduce." << endl;
					cin >> input;
					RatNum red1, red2;
					red1 = red2.reduce(input);
					cout << red1;
				}
				break;

				/*case 8:	//gcd
				{
					RatNum input;
					cout << "Enter the number to find GCD." << endl;
					cin >> input;
					RatNum red1, red2;
					int gcd = gcf(input.A(), input.B());
					cout << gcd;
				}
				break;

				case 9:	//lcd
				{
					cout << "Enter the 2 numbers to find the LCD, seperated by 'L'" << endl;
					RatNum n1, n2;
					char sep;
					cin >> n1 >> sep >> n2;
					int least = lcd(n1, n2);
					cout << least;
				}
				break;*/

				case 10:	//less than
				{
					enterFunction(num1, num2);
					bool less = num1 < num2;
					if (less == true)
						cout << "True" << endl;
					else cout << "False" << endl;
				}
				break;

				case 11:	//less than, equal to
				{
					enterFunction(num1, num2);
					bool less_equal = num1 <= num2;
					if (less_equal == true)
						cout << "True" << endl;
					else cout << "False" << endl;
				}
				break;

				case 12:	//greater than
				{
					enterFunction(num1, num2);
					bool great = num1 > num2;
					if (great == true)
						cout << "True" << endl;
					else cout << "False" << endl;
				}
				break;

				case 13:	//greater than, equal to
				{
					enterFunction(num1, num2);
					bool great_equal = num1 >= num2;
					if (great_equal == true)
						cout << "True" << endl;
					else cout << "False" << endl;
				}
				break;

				case 14: 	//equal
				{
					enterFunction(num1, num2);
					bool equal = num1 == num2;
					if (equal == true)
						cout << "True" << endl;
					else cout << "False" << endl;
				}
				break;

				case 15:	//linear equation
				{
					;
				}
				break;

				default:
					cerr << "Incorrect number entered." << endl;
			}
		}while (op_choice != 16);
		return 0;
}

//enterFunction() accepts input of two rational numbers
void enterFunction(RatNum& n1, RatNum& n2)
{
	cout << "Enter the equation you wish to solve.  Example: 2/3 +4/5"
		<< endl;
	char oper;	//type of arithmetic to perform (+, -, *, /)
	cin >> n1 >> oper >> n2;	//input will be in form of 'a/b + c/d'
}

